Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(97)

Unified Diff: src/interpreter-irregexp.cc

Issue 11600: * Rename to Irregexp throughout.... (Closed) Base URL: http://v8.googlecode.com/svn/branches/experimental/regexp2000/
Patch Set: Created 12 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: src/interpreter-irregexp.cc
===================================================================
--- src/interpreter-irregexp.cc (revision 825)
+++ src/interpreter-irregexp.cc (working copy)
@@ -25,14 +25,14 @@
// (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
// OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
// A simple interpreter for the Regexp2000 byte code.
#include "v8.h"
#include "utils.h"
#include "ast.h"
-#include "bytecodes-re2k.h"
-#include "interpreter-re2k.h"
+#include "bytecodes-irregexp.h"
+#include "interpreter-irregexp.h"
namespace v8 { namespace internal {
@@ -327,10 +327,10 @@
}
-bool Re2kInterpreter::Match(Handle<ByteArray> code_array,
- Handle<String> subject16,
- int* registers,
- int start_position) {
+bool IrregexpInterpreter::Match(Handle<ByteArray> code_array,
+ Handle<String> subject16,
+ int* registers,
+ int start_position) {
ASSERT(StringShape(*subject16).IsTwoByteRepresentation());
ASSERT(subject16->IsFlat(StringShape(*subject16)));
Property changes on: src/interpreter-irregexp.cc
@@ -25,14 +25,14 @@
// (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
// OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
-// A simple interpreter for the Regexp2000 byte code.
+// A simple interpreter for the Irregexp byte code.
#include "v8.h"
#include "utils.h"
___________________________________________________________________
Added: svn:mergeinfo
« no previous file with comments | « src/interpreter-irregexp.h ('k') | src/interpreter-re2k.h » ('j') | src/runtime.cc » ('J')

Powered by Google App Engine
This is Rietveld 408576698